=======================================
Setting up your development environment
=======================================

This tutorial will guide you through all the steps of setting up a development
environment on your machine. The use of virtualenv_ is not mandatory but we strongly
encourage you to use it or something similar in order to simply wipe out any
mistake you can make in the process of creating a package.

Install python (multiple versions?)

Create virtual env

Install pkglts that will install all its dependencies


To go further
=============

See :doc:`pypi`.

.. _virtualenv: https://virtualenv.pypa.io/en/stable/index.html
